@@ -7,6 +7,7 @@ from typing import Any, List, NoReturn, Optional, Type, cast
 import click
 
 from ggshield.output import JSONHandler, OutputHandler, TextHandler
+from ggshield.pre_receive_cmd import prereceive_cmd
 
 from .ci import ci_cmd
 from .config import CONTEXT_SETTINGS, Cache, Config, load_dot_env
@@ -18,7 +19,11 @@ from .ignore import ignore
 from .install import install
 from .quota import quota
 from .status import status
-from .utils import json_output_option_decorator, retrieve_client
+from .utils import (
+    IGNORED_DEFAULT_PATTERNS,
+    json_output_option_decorator,
+    retrieve_client,
+)
 
 
 @click.group(
@@ -26,6 +31,7 @@ from .utils import json_output_option_decorator, retrieve_client
         "commit-range": range_cmd,
         "pre-commit": precommit_cmd,
         "pre-push": prepush_cmd,
+        "pre-receive": prereceive_cmd,
         "ci": ci_cmd,
         "path": path_cmd,
         "repo": repo_cmd,
@@ -71,6 +77,19 @@ from .utils import json_output_option_decorator, retrieve_client
     help="Exclude results from a detector.",
     multiple=True,
 )
+@click.option(
+    "--exclude",
+    default=None,
+    type=click.Path(),
+    help="Do not scan the specified path.",
+    multiple=True,
+)
+@click.option(
+    "--ignore-default-excludes",
+    default=False,
+    is_flag=True,
+    help="Ignore excluded patterns by default. [default: False]",
+)
 @click.pass_context
 def scan(
     ctx: click.Context,
@@ -81,14 +100,21 @@ def scan(
     json_output: bool,
     output: Optional[str],
     banlist_detector: Optional[List[str]] = None,
+    exclude: Optional[List[str]] = None,
+    ignore_default_excludes: bool = False,
 ) -> int:
     """Command to scan various contents."""
     ctx.obj["client"] = retrieve_client(ctx)
     return_code = 0
 
-    ctx.obj["filter_set"] = path_filter_set(
-        Path(os.getcwd()), ctx.obj["config"].paths_ignore
-    )
+    paths_ignore = ctx.obj["config"].paths_ignore
+    if exclude is not None:
+        paths_ignore.update(exclude)
+
+    if not ignore_default_excludes and not ctx.obj["config"].ignore_default_excludes:
+        paths_ignore.update(IGNORED_DEFAULT_PATTERNS)
+
+    ctx.obj["filter_set"] = path_filter_set(Path(os.getcwd()), paths_ignore)
     config: Config = ctx.obj["config"]
 
     if show_secrets is not None:
