@@ -46,6 +46,7 @@ class Config:
     allow_self_signed: bool
     max_commits_for_hook: int
     banlisted_detectors: Set[str]
+    ignore_default_excludes: bool
 
     CONFIG_LOCAL = ["./.gitguardian", "./.gitguardian.yml", "./.gitguardian.yaml"]
     CONFIG_GLOBAL = [
@@ -67,6 +68,7 @@ class Config:
             Attribute("paths_ignore", set()),
             Attribute("show_secrets", False),
             Attribute("verbose", False),
+            Attribute("ignore_default_excludes", False),
         ]
 
         for attr in self.attributes:
@@ -88,6 +90,8 @@ class Config:
             if key in self.get_attributes_keys():
                 if isinstance(getattr(self, key), list):
                     getattr(self, key).extend(item)
+                elif isinstance(getattr(self, key), set):
+                    getattr(self, key).update(item)
                 else:
                     setattr(self, key, item)
             else:
@@ -224,18 +228,8 @@ class Cache:
         else:
             super().__setattr__(name, value)
 
-    def create_empty_cache(self) -> None:
-        # Creates a new file
-        try:
-            with open(self.CACHE_FILENAME, "w"):
-                pass
-        except PermissionError:
-            # Hotfix: for the time being we skip cache handling if permission denied
-            pass
-
     def load_cache(self) -> bool:
         if not os.path.isfile(self.CACHE_FILENAME):
-            self.create_empty_cache()
             return True
 
         _cache: dict = {}
@@ -286,9 +280,6 @@ class Cache:
         return _cache
 
     def save(self) -> bool:
-        if not os.path.isfile(self.CACHE_FILENAME):
-            return False
-
         try:
             f = open(self.CACHE_FILENAME, "w")
         except PermissionError:
