@@ -1,5 +1,6 @@
 import os
 import re
+import traceback
 from enum import Enum
 from typing import Iterable, List, Optional
 
@@ -28,6 +29,27 @@ REGEX_HEADER_INFO = re.compile(
 EMPTY_SHA = "0000000000000000000000000000000000000000"
 EMPTY_TREE = "4b825dc642cb6eb9a060e54bf8d69288fbee4904"
 
+# GitHub timeouts every pre-receive hook after 5s with an error.
+# We try and anticipate that so we can control the return code
+PRERECEIVE_TIMEOUT = 4.5
+
+IGNORED_DEFAULT_PATTERNS = [
+    "**/.git/**/*",
+    "**/.pytest_cache/**/*",
+    "**/.mypy_cache/**/*",
+    "**/.venv/**/*",
+    "**/.eggs/**/*",
+    "**/.eggs-info/**/*",
+    "**/vendor/**/*",
+    "**/vendors/**/*",
+    "**/node_modules/**/*",
+    "top-1000.txt*",
+    "**/*.storyboard*",
+    "**/*.xib",
+    "**/*.mdx*",
+    "**/*.sops",
+]
+
 
 class Filemode(Enum):
     """
@@ -198,6 +220,7 @@ class SupportedScanMode(Enum):
     COMMIT_RANGE = "commit_range"
     PRE_COMMIT = "pre_commit"
     PRE_PUSH = "pre_push"
+    PRE_RECEIVE = "pre_receive"
     CI = "ci"
     DOCKER = "docker"
 
@@ -231,3 +254,17 @@ def retrieve_client(ctx: click.Context) -> GGClient:
         timeout=60,
         session=session,
     )
+
+
+def handle_exception(e: Exception, verbose: bool) -> int:
+    """
+    Handle exception from a scan command.
+    """
+    if isinstance(e, click.exceptions.Abort):
+        return 0
+    elif isinstance(e, click.ClickException):
+        raise e
+    else:
+        if verbose:
+            traceback.print_exc()
+        raise click.ClickException(str(e))
